@@ -1153,6 +1153,14 @@ my %sSubVersion = (
         Notes => 'newer version of XML raw processing settings',
         Binary => 1,
     },
+    # more tags (ref forum6840)
+    FixtureIdentifier   => { Avoid => 1 },
+    EditStatus          => { Avoid => 1 },
+    ReleaseDate         => { Avoid => 1 },
+    ReleaseTime         => { Avoid => 1 },
+    OriginatingProgram  => { Avoid => 1 },
+    ObjectCycle         => { Avoid => 1 },
+    Snapshots           => { Avoid => 1, List => 'Bag' },
 );
 
 # Picture Licensing Universal System namespace properties (xmpPLUS)
@@ -1551,7 +1559,7 @@ This file contains definitions for less common XMP namespaces.
 
 =head1 AUTHOR
 
-Copyright 2003-2015, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2016, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
